import React from 'react';

import { Menu } from 'semantic-ui-react';

export default function Example() {
  return (
    <Menu>
      <Menu.Item>
        ← cursor here
      </Menu.Item>
    </Menu>
  );
}
