<div>
  {% set foo = 'bar' %}

  {% if someting %}

    {% trans %}

    {% endtrans %}

  {% else %}

    {% for x in [1, 2, 3]  %}
      <span>a</span>
    {% else %}
      <span>b</span>
    {% endfor %}

  {% endif %}

</div>
